load

Function load 

pub fn load(
    sandbox: &Sandbox,
    root: &RuleRoot,
    config_path: &Path,
) -> Result<Config, ConfigError>
Load and validate a configuration.

Errors

Returns ConfigError when the file cannot be read, the module fails to evaluate, or the result is not shaped like a config.